@@ -369,7 +369,7 @@ setGeneric("summary", function(object, ...)
 setMethod("summary", "ABCXYZData", function(object, withMissing = FALSE) {
   temp = as.data.table(object@data)
   summary = temp %>%
-    group_by(.dots = "class") %>%
+    group_by(pick(all_of("class"))) %>%
     summarize(items = n(), sum = sum(get(object@value), na.rm = TRUE)) %>%
     as.data.table
 
